summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kpayeesview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kpayeesview.h')
-rw-r--r--kmymoney2/views/kpayeesview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/views/kpayeesview.h b/kmymoney2/views/kpayeesview.h
index f4a481e..95be179 100644
--- a/kmymoney2/views/kpayeesview.h
+++ b/kmymoney2/views/kpayeesview.h
@@ -147,12 +147,12 @@ public:
/**
* Constructor to be used to construct a payee entry object.
*
* @param tqparent pointer to the KListView object this entry should be
* added to.
* @param payee const reference to MyMoneyPayee for which
* the KListView entry is constructed
*/
- KPayeeListItem(KListView *tqparent, const MyMoneyPayee& payee);
+ KPayeeListItem(KListView *parent, const MyMoneyPayee& payee);
~KPayeeListItem();
/**
@@ -175,7 +175,7 @@ private:
class KTransactionListItem : public KListViewItem
{
public:
- KTransactionListItem(KListView* view, KTransactionListItem* tqparent, const TQString& accountId, const TQString& transaction);
+ KTransactionListItem(KListView* view, KTransactionListItem* parent, const TQString& accountId, const TQString& transaction);
~KTransactionListItem();
const TQString& transactionId(void) const { return m_transactionId; };
@@ -203,7 +203,7 @@ class KPayeesView : public KPayeesViewDecl
TQ_OBJECT
public:
- KPayeesView(TQWidget *tqparent=0, const char *name=0);
+ KPayeesView(TQWidget *parent=0, const char *name=0);
~KPayeesView();
void show(void);
@@ -147,12 +147,12 @@ public:
* Constructor to be used to construct a payee entry object.
*
- * @param tqparent pointer to the KListView object this entry should be
+ * @param parent pointer to the KListView object this entry should be
* added to.
* @param payee const reference to MyMoneyPayee for which